from enum import Enum


class GameMode(Enum):
    """
    Represents all possible game modes in Brawl Stars.

    Attributes:
        SOLO_SHOWDOWN: Solo Showdown mode.
        DUO_SHOWDOWN: Duo Showdown mode.
        HEIST: Heist mode.
        BOUNTY: Bounty mode.
        SIEGE: Siege mode.
        GEM_GRAB: Gem Grab mode.
        BRAWL_BALL: Brawl Ball mode.
        BIG_GAME: Big Game mode.
        BOSS_FIGHT: Boss Fight mode.
        ROBO_RUMBLE: Robo Rumble mode.
        TAKEDOWN: Takedown mode.
        LONE_STAR: Lone Star mode.
        PRESENT_PLUNDER: Present Plunder mode.
        HOT_ZONE: Hot Zone mode.
        SUPER_CITY_RAMPAGE: Super City Rampage mode.
        KNOCKOUT: Knockout mode.
        VOLLEY_BRAWL: Volley Brawl mode.
        BASKET_BRAWL: Basket Brawl mode.
        HOLD_THE_TROPHY: Hold the Trophy mode.
        TROPHY_THIEVES: Trophy Thieves mode.
        DUELS: Duels mode.
        WIPEOUT: Wipeout mode.
        PAYLOAD: Payload mode.
        BOT_DROP: Bot Drop mode.
        HUNTERS: Hunters mode.
        LAST_STAND: Last Stand mode.
        SNOWTEL_THIEVES: Snowtel Thieves mode.
        PUMPKIN_PLUNDER: Pumpkin Plunder mode.
        TROPHY_ESCAPE: Trophy Escape mode.
        WIPEOUT_5V5: Wipeout 5v5 mode.
        KNOCKOUT_5V5: Knockout 5v5 mode.
        GEM_GRAB_5V5: Gem Grab 5v5 mode.
        BRAWL_BALL_5V5: Brawl Ball 5v5 mode.
        GODZILLA_CITY_SMASH: Godzilla City Smash mode.
        PAINT_BRAWL: Paint Brawl mode.
        TRIO_SHOWDOWN: Trio Showdown mode.
        ZOMBIE_PLUNDER: Zombie Plunder mode.
        JELLYFISHING: Jellyfishing mode.
        UNKNOWN: Unknown mode.
    """

    SOLO_SHOWDOWN = "soloShowdown"
    DUO_SHOWDOWN = "duoShowdown"
    HEIST = "heist"
    BOUNTY = "bounty"
    SIEGE = "siege"
    GEM_GRAB = "gemGrab"
    BRAWL_BALL = "brawlBall"
    BIG_GAME = "bigGame"
    BOSS_FIGHT = "bossFight"
    ROBO_RUMBLE = "roboRumble"
    TAKEDOWN = "takedown"
    LONE_STAR = "loneStar"
    PRESENT_PLUNDER = "presentPlunder"
    HOT_ZONE = "hotZone"
    SUPER_CITY_RAMPAGE = "superCityRampage"
    KNOCKOUT = "knockout"
    VOLLEY_BRAWL = "volleyBrawl"
    BASKET_BRAWL = "basketBrawl"
    HOLD_THE_TROPHY = "holdTheTrophy"
    TROPHY_THIEVES = "trophyThieves"
    DUELS = "duels"
    WIPEOUT = "wipeout"
    PAYLOAD = "payload"
    BOT_DROP = "botDrop"
    HUNTERS = "hunters"
    LAST_STAND = "lastStand"
    SNOWTEL_THIEVES = "snowtelThieves"
    PUMPKIN_PLUNDER = "pumpkinPlunder"
    TROPHY_ESCAPE = "trophyEscape"
    WIPEOUT_5V5 = "wipeout5V5"
    KNOCKOUT_5V5 = "knockout5V5"
    GEM_GRAB_5V5 = "gemGrab5V5"
    BRAWL_BALL_5V5 = "brawlBall5V5"
    GODZILLA_CITY_SMASH = "godzillaCitySmash"
    PAINT_BRAWL = "paintBrawl"
    TRIO_SHOWDOWN = "trioShowdown"
    ZOMBIE_PLUNDER = "zombiePlunder"
    JELLYFISHING = "jellyfishing"
    UNKNOWN = "unknown"
